@@ -5,6 +5,7 @@ import logging
 from src.jobs import products_jobs
 from src.jobs import stock_jobs
 from src.jobs import price_jobs
+from src.jobs import order_jobs
 from src.api import oking
 
 logger = logging.getLogger()
@@ -107,13 +108,14 @@ def instantiate_send_products_job(job_config: dict) -> None:
 
 # region Pedidos
 
-def instantiate_internalize_orders_job(job_config: dict) -> None:
+def instantiate_orders_job(job_config: dict) -> None:
     """
     Instancia o job de envio dos estoques para a api okVendas
     Args:
         job_config: Configuração do job obtida na api do oking
     """
     logger.info(job_config.get('job_name') + ' | Iniciando execucao')
+    order_jobs.define_job_start(job_config)
 
 # endregion Pedidos
 
@@ -147,7 +149,7 @@ def get_job_from_name(job_name: str):
     elif job_name == 'envia_catalogo_produto_loja_job':
         return instantiate_send_products_job
     elif job_name == 'internaliza_pedidos_job':
-        return instantiate_internalize_orders_job
+        return instantiate_orders_job
 
 # endregion ConfigJobs
 
